pub struct AdoptArgs {
pub path: PathBuf,
pub dry_run: bool,
}Fields
path: PathBufPath to an unmanaged item under a managed target directory.
dry_run: boolShow what would happen without moving content or syncing.