pub struct AgentCopyConfig {
pub harnesses: Vec<String>,
pub include_fanout: bool,
}Expand description
Selective native agent emission under managed mode or agent_emission = "never".
Fields
harnesses: Vec<String>include_fanout: boolTrait Implementations
Sourceimpl Clone for AgentCopyConfig
impl Clone for AgentCopyConfig
Sourcefn clone(&self) -> AgentCopyConfig
fn clone(&self) -> AgentCopyConfig
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AgentCopyConfig
impl Debug for AgentCopyConfig
Sourceimpl Default for AgentCopyConfig
impl Default for AgentCopyConfig
Sourcefn default() -> AgentCopyConfig
fn default() -> AgentCopyConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for AgentCopyConfig
impl<'de> Deserialize<'de> for AgentCopyConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for AgentCopyConfig
impl PartialEq for AgentCopyConfig
Sourcefn eq(&self, other: &AgentCopyConfig) -> bool
fn eq(&self, other: &AgentCopyConfig) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for AgentCopyConfig
impl Serialize for AgentCopyConfig
impl StructuralPartialEq for AgentCopyConfig