pub struct ModelPolicyRule {
pub match_type: ModelPolicyMatchType,
pub match_value: String,
pub no_fallback: bool,
pub overrides: Mapping,
}Expand description
Shared model-policy rule type used by profile frontmatter, agent overlays, and settings-level model policies.
Fields
match_type: ModelPolicyMatchTypematch_value: Stringno_fallback: booloverrides: MappingTrait Implementations
Sourceimpl Clone for ModelPolicyRule
impl Clone for ModelPolicyRule
Sourcefn clone(&self) -> ModelPolicyRule
fn clone(&self) -> ModelPolicyRule
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ModelPolicyRule
impl Debug for ModelPolicyRule
Sourceimpl<'de> Deserialize<'de> for ModelPolicyRule
impl<'de> Deserialize<'de> for ModelPolicyRule
Sourcefn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>where
D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for ModelPolicyRule
impl PartialEq for ModelPolicyRule
Sourcefn eq(&self, other: &ModelPolicyRule) -> bool
fn eq(&self, other: &ModelPolicyRule) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ModelPolicyRule
impl Serialize for ModelPolicyRule
impl StructuralPartialEq for ModelPolicyRule