Module lock

Module lock 

Re-exports

pub use crate::types::ItemId;
pub use crate::types::ItemKind;

Structs

LockFile
The complete lock file — ownership registry for all managed items.
LockedItem
One installed item tracked by the lock.
LockedSource
One resolved source in the lock.

Functions

build
Build a new lock file from resolved graph + apply results.
load
Load the lock file from the given root directory.
write
Write the lock file atomically to the given root directory.