pub struct CompiledNativeOutput {
pub owner_canonical_dest_path: String,
pub target_root: String,
pub dest_path: String,
pub installed_checksum: ContentHash,
}Expand description
Native harness output recorded in the lock for a canonical .mars agent item.
Fields
owner_canonical_dest_path: StringCanonical .mars dest path for the owning agent (e.g. agents/coder.md).
target_root: Stringdest_path: Stringinstalled_checksum: ContentHashTrait Implementations
Sourceimpl Clone for CompiledNativeOutput
impl Clone for CompiledNativeOutput
Sourcefn clone(&self) -> CompiledNativeOutput
fn clone(&self) -> CompiledNativeOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompiledNativeOutput
impl Debug for CompiledNativeOutput
Sourceimpl PartialEq for CompiledNativeOutput
impl PartialEq for CompiledNativeOutput
Sourcefn eq(&self, other: &CompiledNativeOutput) -> bool
fn eq(&self, other: &CompiledNativeOutput) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CompiledNativeOutput
impl StructuralPartialEq for CompiledNativeOutput