Module path_syntax

Module path_syntax 

Source string syntax classification.

Determines whether a CLI/config source string is a local path or a source identifier.

Functions

classify_local_source
Classify a source string as a local path if it matches local path syntax.