External process invocation.
Centralizes git and other external tool execution.
Functions
- display_
command - Display a command for error messages (not for execution).
- run_git
- Run a git command and return stdout on success.
- run_
git_ raw - Run a git command and return the raw
Output, allowing caller to handle exit codes. - run_
git_ with_ ref - Run a git command with a specific ref argument that may contain special characters.