run_git_with_ref

Function run_git_with_ref 

pub fn run_git_with_ref(
    base_args: &[&str],
    ref_arg: &str,
    cwd: &Path,
    context: &str,
) -> Result<String, MarsError>
Run a git command with a specific ref argument that may contain special characters.

Wraps run_git but takes the ref as a separate argument to ensure it’s passed correctly.