pub enum VersionCheckResult {
NotSeen,
SameVersion,
PotentiallyConflicting {
existing: VersionConstraint,
requested: VersionConstraint,
},
DifferentVersion {
existing: VersionConstraint,
requested: VersionConstraint,
},
}Expand description
Result of checking whether an item was seen already.
Variants
NotSeen
Item has not been visited yet.
SameVersion
Item was visited with a compatible version.
PotentiallyConflicting
Item was visited with a potentially conflicting version (latest vs pinned).
DifferentVersion
Item was visited with a conflicting version.