pub struct PackageVersions { /* private fields */ }Expand description
Tracks resolved version per package and rejects divergent refs.
Implementations
Sourceimpl PackageVersions
impl PackageVersions
pub fn new() -> Self
Sourcepub fn check_or_insert(
&mut self,
package: &SourceName,
resolved: &ResolvedRef,
requested: &VersionConstraint,
required_by: &str,
is_local: bool,
) -> Result<(), ResolutionError>
pub fn check_or_insert( &mut self, package: &SourceName, resolved: &ResolvedRef, requested: &VersionConstraint, required_by: &str, is_local: bool, ) -> Result<(), ResolutionError>
Check existing package version or insert if first time seen.