pub fn parse(input: &str) -> Result<ParsedSourceSpec, ParseError>Expand description
Parse a source specifier into a normalized structured value.
pub fn parse(input: &str) -> Result<ParsedSourceSpec, ParseError>Parse a source specifier into a normalized structured value.