Module rewrite

Module rewrite 

Frontmatter skill reference rewriting after collision-driven renames.

When a collision forces a rename and affected agents have frontmatter skills: references to the renamed skill, this module rewrites those references to point at the correct renamed version.

Functions

rewrite_skill_refs
Rewrite frontmatter skill references for renamed transitive deps.