pub struct AgentsAdapter;Trait Implementations
Sourceimpl Debug for AgentsAdapter
impl Debug for AgentsAdapter
Sourceimpl TargetAdapter for AgentsAdapter
impl TargetAdapter for AgentsAdapter
Sourcefn skill_variant_key(&self) -> Option<&str>
fn skill_variant_key(&self) -> Option<&str>
Skill variant harness key used when projecting skills to this target. Read more
Sourcefn default_dest_path(&self, kind: ItemKind, name: &str) -> Option<DestPath>
fn default_dest_path(&self, kind: ItemKind, name: &str) -> Option<DestPath>
Default destination path for an item of the given kind and name. Read more
Sourcefn write_config_entries(
&self,
_entries: &[ConfigEntry],
_target_dir: &Path,
) -> Result<Vec<PathBuf>, MarsError>
fn write_config_entries( &self, _entries: &[ConfigEntry], _target_dir: &Path, ) -> Result<Vec<PathBuf>, MarsError>
Write config entries (MCP servers, hooks) to this target’s config file. Read more
Sourcefn emit_pre_write_diagnostics(
&self,
_entries: &[ConfigEntry],
_diag: &mut DiagnosticCollector,
)
fn emit_pre_write_diagnostics( &self, _entries: &[ConfigEntry], _diag: &mut DiagnosticCollector, )
Emit target-specific pre-write diagnostics (e.g., lossiness warnings). Read more