pub struct CodexAdapter;Trait Implementations
Sourceimpl Debug for CodexAdapter
impl Debug for CodexAdapter
Sourceimpl TargetAdapter for CodexAdapter
impl TargetAdapter for CodexAdapter
Sourcefn skill_variant_key(&self) -> Option<&str>
fn skill_variant_key(&self) -> Option<&str>
Skill variant harness key used when projecting skills to this target. Read more
Sourcefn default_dest_path(&self, kind: ItemKind, name: &str) -> Option<DestPath>
fn default_dest_path(&self, kind: ItemKind, name: &str) -> Option<DestPath>
Default destination path for an item of the given kind and name. Read more
Sourcefn write_config_entries(
&self,
entries: &[ConfigEntry],
target_dir: &Path,
) -> Result<Vec<PathBuf>, MarsError>
fn write_config_entries( &self, entries: &[ConfigEntry], target_dir: &Path, ) -> Result<Vec<PathBuf>, MarsError>
Write config entries (MCP servers, hooks) to this target’s config file. Read more
Sourcefn emit_pre_write_diagnostics(
&self,
entries: &[ConfigEntry],
target_dir: &Path,
diag: &mut DiagnosticCollector,
)
fn emit_pre_write_diagnostics( &self, entries: &[ConfigEntry], target_dir: &Path, diag: &mut DiagnosticCollector, )
Emit target-specific pre-write diagnostics (e.g., lossiness warnings). Read more