pub enum ConfigEntry {
McpServer(McpServerEntry),
Hook(HookEntry),
}Expand description
A config entry to be written to a target’s config file.
Adapters consume these entries to write or update target-specific config files (MCP JSON, hooks in settings.json, etc.).
Variants
McpServer(McpServerEntry)
An MCP server entry to register in the target’s MCP config file.
Hook(HookEntry)
A hook binding to register in the target’s hook config.
Implementations