pub struct DestPath(/* private fields */);Expand description
Normalized relative path coordinate (always forward-slash).
Use resolve(root) to get a native filesystem path.
Implementations
Sourceimpl DestPath
impl DestPath
Sourcepub fn new(value: impl AsRef<str>) -> Result<Self, DestPathError>
pub fn new(value: impl AsRef<str>) -> Result<Self, DestPathError>
Create from any string, normalizing separators and rejecting invalid paths.
Sourcepub fn resolve(&self, root: &Path) -> PathBuf
pub fn resolve(&self, root: &Path) -> PathBuf
Resolve to a native filesystem path under the given root.
Sourcepub fn components(&self) -> impl Iterator<Item = &str>
pub fn components(&self) -> impl Iterator<Item = &str>
Split into path components (by forward slash).