pub struct SourceSubpath(/* private fields */);Expand description
Normalized relative package coordinate under a fetched source root.
Implementations
Sourceimpl SourceSubpath
impl SourceSubpath
pub fn new(value: impl AsRef<str>) -> Result<Self, SourceSubpathError>
pub fn as_str(&self) -> &str
pub fn as_path(&self) -> &Path
pub fn into_inner(self) -> String
Sourcepub fn join_under(&self, base: &Path) -> Result<PathBuf, SourceSubpathError>
pub fn join_under(&self, base: &Path) -> Result<PathBuf, SourceSubpathError>
Join this relative subpath under base, rejecting traversal attempts.