Skip to main contentModule lock
Source pub use crate::types::ItemId;pub use crate::types::ItemKind;
- LockFile
- The complete lock file — ownership registry for all managed items.
- LockedItem
- One installed item tracked by the lock.
- LockedSource
- One resolved source in the lock.
- build
- Build a new lock file from resolved graph + apply results.
- load
- Load the lock file from the given root directory.
- write
- Write the lock file atomically to the given root directory.