Source string syntax classification.
Determines whether a CLI/config source string is a local path or a source identifier.
Functions
- classify_
local_ source - Classify a source string as a local path if it matches local path syntax.