pub struct CursorAdapter;Implementations
Sourceimpl CursorAdapter
impl CursorAdapter
Sourcepub fn emit_hook_lossiness_diagnostics(
entries: &[ConfigEntry],
diag: &mut DiagnosticCollector,
)
pub fn emit_hook_lossiness_diagnostics( entries: &[ConfigEntry], diag: &mut DiagnosticCollector, )
Emit diagnostics for any hook entries in entries (all dropped for Cursor).
Called by the compiler before write_config_entries so that the
lossiness is reported even though hooks are silently skipped in write.