pub struct OpencodeAdapter;Trait Implementations
Sourceimpl Debug for OpencodeAdapter
impl Debug for OpencodeAdapter
Sourceimpl TargetAdapter for OpencodeAdapter
impl TargetAdapter for OpencodeAdapter
Sourcefn skill_variant_key(&self) -> Option<&str>
fn skill_variant_key(&self) -> Option<&str>
Skill variant harness key used when projecting skills to this target. Read more
Sourcefn default_dest_path(&self, kind: ItemKind, name: &str) -> Option<DestPath>
fn default_dest_path(&self, kind: ItemKind, name: &str) -> Option<DestPath>
Default destination path for an item of the given kind and name. Read more
Sourcefn write_config_entries(
&self,
entries: &[ConfigEntry],
target_dir: &Path,
) -> Result<Vec<PathBuf>, MarsError>
fn write_config_entries( &self, entries: &[ConfigEntry], target_dir: &Path, ) -> Result<Vec<PathBuf>, MarsError>
Write config entries (MCP servers, hooks) to this target’s config file. Read more
Sourcefn remove_config_entries(
&self,
entry_keys: &[String],
target_dir: &Path,
) -> Result<(), MarsError>
fn remove_config_entries( &self, entry_keys: &[String], target_dir: &Path, ) -> Result<(), MarsError>
Remove stale config entries from this target’s config file. Read more
Sourcefn emit_pre_write_diagnostics(
&self,
_entries: &[ConfigEntry],
_target_dir: &Path,
_diag: &mut DiagnosticCollector,
)
fn emit_pre_write_diagnostics( &self, _entries: &[ConfigEntry], _target_dir: &Path, _diag: &mut DiagnosticCollector, )
Emit target-specific pre-write diagnostics (e.g., lossiness warnings). Read more